// Copyright (c) 2016-2022 Knuth Project developers.
// Distributed under the MIT software license, see the accompanying
// file COPYING or http://www.opensource.org/licenses/mit-license.php.

#define PY_SSIZE_T_CLEAN
#include <Python.h>
#include "structmember.h"

#include <kth/py-native/node.h>
#include <kth/py-native/utils.h>

#include <kth/capi.h>

#include <kth/capi/config/database_settings.h>

#include <kth/py-native/config/database_settings.h>
// #include <kth/py-native/helper.h>



#ifdef __cplusplus
extern "C" {
#endif

#ifdef __cplusplus
} // extern "C"
#endif
